################################################################################
# solar/fake.py: Fake model for the solar flux density at 1 AU. Used for
# testing.
################################################################################

import numpy as np
import tabulation as tab

# Column 1 is wavelength in microns
# Column 2 is solar F (not flux density) at 1 AU in W/m^2/Hz

FAKE_ARRAY = np.array([
    0.16, 1,
    0.20, 1,
    0.2000000001, 1e-20,  # Tabulation does not like having 0 values in the
    0.5999999999, 1e-20,  # middle of the flux density array
    0.60, 2,
    0.66, 2
])

FAKE_ARRAY = FAKE_ARRAY.reshape(FAKE_ARRAY.size//2, 2)

FAKE_WAVELENGTH_MICRON = FAKE_ARRAY[:, 0]
FAKE_FLUX_PER_HZ = FAKE_ARRAY[:, 1] * np.pi  # Column is F, not pi*F

FLUX_DENSITY = tab.Tabulation(FAKE_WAVELENGTH_MICRON, FAKE_FLUX_PER_HZ)
UNITS = 'W/m^2/um'
XUNITS = 'um'

################################################################################



################################################################################
# solar/stis_rieke.py: STIS and Rieke models merged.
################################################################################

import numpy as np

import solar.stis as stis
import solar.rieke as rieke

import tabulation as tab

assert stis.UNITS == rieke.UNITS
assert stis.XUNITS == rieke.XUNITS

tab1 = stis.FLUX_DENSITY
tab2 = rieke.FLUX_DENSITY

mask = (tab2.x > np.max(tab1.x))

merged_x = np.hstack((tab1.x, tab2.x[mask]))
merged_y = np.hstack((tab1.y, tab2.y[mask]))

FLUX_DENSITY = tab.Tabulation(merged_x, merged_y)
UNITS = stis.UNITS
XUNITS = stis.XUNITS

################################################################################
